Tournament Leicester, England August 14th 2005 14 players Phil Thompson True Love and Loyalty Just an attempt to do block denial while avoiding Necrobleed. Originally used Kahina and Khaytall with added Pulse and Seduction but found it too slow off the mark. As with all block denial speed helps enormously as most damage is done early. Possible advantages over standard Necrobleed include tapping with Faceless Night and a chance to cancel bounce with Approximation. True Love's Face followed by Elder Impersonation is always fun ! Crypt (12 cards, min=18, max=30, avg=6.17) ------------------------------------------ 2x Intisar 8 OBF PRE SER cel pot Follower of Set:2 2x Qufur am-Heru 7 OBF PRE SER cel tha Follower of Set:2 2x Sarrasine 7 OBF PRE aus nec ser Follower of Set:2 2x Samat Ramal-Ra, Archon 6 OBF pre ser tha Follower of Set:2 2x Count Ormonde 5 OBF dom pre ser Follower of Set:2 1x Hadrian Garrick 4 obf pre Follower of Set:2 1x Nepata 4 obf pre ser Follower of Set:2 Library (90 cards) Master (15) 2x Anarch Troublemaker 1x Barrens, The 2x Blood Doll 2x Dreams of the Sphinx 1x Elder Library 1x Khobar Towers, Al-Khubar 1x Opium Den 2x Perfectionist 2x Presence 1x Secret Horde Action (19) 2x Blood Bond 4x Enchant Kindred 2x Form of Corruption 1x Intimidation 4x Legal Manipulations 2x Mind Numb 4x Social Charm Equipment (2) 1x Learjet 1x Signet of King Saul, The Action Modifier (42) 8x Approximation of Loyalty 4x Change of Target 10x Elder Impersonation 8x Faceless Night 4x Spying Mission 8x True Love's Face Combat (12) 6x Catatonic Fear 6x Majesty